from typing import Optional

def recursive_fibonnaci_number(number: int) -> Optional[int]:
    if number < 0:
        return None
    elif number <= 1:
        return number
    else:
        return recursive_fibonnaci_number(number - 1) + recursive_fibonnaci_number(number - 2)


from unittest import main, TestCase

from nico_fib_py.fib_calcs.fib_number import recursive_fibonnaci_number


class RecursiveFibonacciNumberTest(TestCase):

    def test_zero(self):
        self.assertEqual(0, recursive_fibonnaci_number(number=0))

    def test_negative(self):
        self.assertEqual(None, recursive_fibonnaci_number(number=-1))

    def test_one(self):
        self.assertEqual(1, recursive_fibonnaci_number(number=1))

    def test_two(self):
        self.assertEqual(1, recursive_fibonnaci_number(number=2))

    def test_twenty(self):
        self.assertEqual(6765, recursive_fibonnaci_number(number=20))

if __name__ == "__main__":
    main()


from importlib.metadata import entry_points
from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()


setup(
    name="nico_fib_py",
    version="0.0.1",
    author="NK",
    author_email="nicolas.kateb@yahoo.fr",
    description="Calculates a Fibonacci number",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nicolask-perso/nico-fib.git",
    install_requires=[],
    packages=find_packages(exclude=("tests")),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    entry_points={
        'console_scripts': [
            'fib-number = nico_fib_py.cmd.fib_number:fib_numb',
        ],
    },
    python_requires='>=3',
    tests_require=['pytest'],
)